/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkXMLReaderVersion.h

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
/**
 * @class   vtkXMLReaderVersion
 * @brief   version number for legacy readers/writers
 */

#ifndef vtkXMLReaderVersion_h
#define vtkXMLReaderVersion_h

VTK_ABI_NAMESPACE_BEGIN
const int vtkXMLReaderMajorVersion = 2;
const int vtkXMLReaderMinorVersion = 2;

VTK_ABI_NAMESPACE_END
#endif // vtkXMLReaderVersion_h
// VTK-HeaderTest-Exclude: vtkXMLReaderVersion.h
